^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
Changelog for package lanelet2_maps
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

1.2.1 (2023-05-10)
------------------

1.2.0 (2023-01-30)
------------------
* Add CI using GitHub Actions (`#256 <https://github.com/fzi-forschungszentrum-informatik/Lanelet2/issues/256>`_)
* Distinguish relations and their members in maps README.md
  In description of Lanelets
* Contributors: Michael Hoss, Nico Neumann, Fabian Immel

1.1.1 (2020-09-14)
------------------

1.1.0 (2020-09-06)
------------------
* Add experimental support for building with colcon on ros2 and ament_cmake
* Updating package.xml files to format 3.
* Contributors: Fabian Poggenhans, Joshua Whitley

1.0.1 (2020-03-24)
------------------
* Make sure lanelet2 buildtool_export_depends on mrt_cmake_modules
* Add changelogs
* Contributors: Fabian Poggenhans

1.0.0 (2020-03-03)
------------------
* Bump version to 1.0
* Improve presets and lanelet visualization
* added swedish traffic signs
* Clean up JOSM style sheet
* Add US traffic signs to JOSM stylesheet and docu
* Improve documentation on how traffic lights/signs should be mapped
* Add documentation
* Fix example map
* Initial commit
* Contributors: Fabian Poggenhans, Lingguang Wang, Maximilian Naumann
